/* DI switch bank routing
 * Michael Robinson */

`timescale 1ns/10ps

/* Data switch router module
 * Input: [7:0] di = data switches
 *        write_en_ = Active low.  Clears off ddbus so switch data may be
 *                    written to memory.  When high, processor has control
 *                    of ddbus.
 *        sre_ = When halted, switches refer to state register
 *        pre_ = When halted, switches refer to page register
 *        mee_ = When halted, switches refer to memory/devices
 *        i1e_ = When halted, switches refer to first instruction word
 *        i2e_ = When halted, switches refer to second instruction word
 *        i3e_ = When halted, switches refer to third instruction word
 * Output:
 *        mew_ = when low, signals memory/device write operation is forthcoming
 *        enrr = when low, requests that other devices relinquish ddbus
 *        [7:0] ddbus = switch data routed to data bus
 *        [7:0] dii1 = switch data routed to first instruction word
 *        [7:0] ablo = switch data routed to second instruction word
 *        [7:0] dii3 = switch data routed to third instruction word
 */
module diroute( di, pre_, i1e_, i2e_, i3e_, sre_, mee_, write_en_, 
                mew_, enrr, ddbus, dii1, ablo, dii3 );
input [7:0] di;
input pre_, i1e_, i2e_, i3e_, sre_, mee_, write_en_;
output mew_, enrr;
output [7:0] ddbus, dii1, ablo, dii3;

wire mew_;
wire enrr;
wire eni3;

assign mew_ = write_en_ | mee_;
assign enrr = pre_ & mew_;
assign eni3 = i3e_ & sre_;

u74ls244 dime( .d(di), .q(ddbus), .oe_(enrr) );
u74ls244 di1( .d(di), .q(dii1), .oe_(i1e_) );
u74ls244 di2( .d(di), .q(ablo), .oe_(i2e_) );
u74ls244 di3( .d(di), .q(dii3), .oe_(eni3) );
 
endmodule